@@ -2,7 +2,7 @@
 
 package WebService::OpenSky::Core::Flight;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Moose;
 use experimental qw(signatures);
@@ -39,7 +39,16 @@ WebService::OpenSky::Core::Flight - Flight class
 
 =head1 VERSION
 
-version 0.006
+version 0.007
+
+=head1 SYNOPSIS
+
+    use WebService::OpenSky;
+    my $opensky = WebService::OpenSky->new;
+    my $flights  = $opensky->get_arrivals_by_airport('KLAX', $start, $end);
+    while ( my $flight = $flights->next ) {
+        say $flight->callsign;
+    }
 
 =head1 DESCRIPTION
 
