@@ -2,7 +2,7 @@
 
 package WebService::OpenSky::Core::StateVector;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 use Moose;
 use experimental qw(signatures);
 
@@ -94,15 +94,18 @@ WebService::OpenSky::Core::StateVector - A class representing a state from the O
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
     use WebService::OpenSky;
     my $opensky = WebService::OpenSky->new;
     my $states  = $opensky->get_states;
-    my $state   = $states->[0];
-    say $state->callsign;
+    while ( my $vector = $states->next ) {
+        say $vector->callsign;
+        say $vector->latitude;
+        say $vector->longitude;
+    }
 
 =head1 DESCRIPTION
 
